//libraries and objects creation
#include <Wire.h>
// =====================================
// Constants
int SoilMoisturPin = A0;               // connected to sensor
int BattValuePin = A1;                 // connected to test batterie
int DonePin = 7;                       // connected to TPL5110 DONE
int LedPin = 8;                        // connected to led (blinks on reset)
int BuzzerPin = 9;                     // connected to active buzzer
int SoilMoistureValue = 0;             // variable to store value read on soilMoisturPin
int BattValue = 0;                     // variable to store value read on BattValuePin
int SoilMoistureMin = 634;             // value above which watering is considered necessary
int BattValueMin = 570;                // value below which the battery is discharged (for me 3.5V)
bool DisplayMode = true;              // Indicates if serial monitor must be used to display variables. For testing purpose

void setup() { 
   pinMode(DonePin, OUTPUT);           // TPL5110 pin
   pinMode(SoilMoisturPin, INPUT);     // sensor pin
   pinMode(BattValuePin, INPUT);       // battery pin
   pinMode (BuzzerPin, OUTPUT);        // buzzer pin
   pinMode (LedPin, OUTPUT);           // Led
   digitalWrite(BuzzerPin, LOW);       // Buzzer off
   digitalWrite(LedPin, HIGH);         // led on to inform all is OK. controler is working fine
   delay(1000);
   digitalWrite(LedPin, LOW);          // led off
   Serial.begin(115200);               // for testing purpose
   }

void loop() {
   SoilMoistureValue = analogRead(SoilMoisturPin);  // read sensor
   BattValue = analogRead(BattValuePin);            // read battery level 
   if (DisplayMode == true) {display(); }           // display infos in testing mode
   if (BattValue < BattValueMin) {                  // batterie level to low 
    for (int i = 0; i <= 30; i++) {                 // Sends an alternate sound  
      if (DisplayMode == true) {display(); }
      digitalWrite(BuzzerPin, HIGH);    // buzzer on
      delay(500);
      digitalWrite(BuzzerPin, LOW);     // buzzer off
      delay(500);
   }
   }
   if (SoilMoistureValue > SoilMoistureMin)  { // sensor detects dry soil
     digitalWrite(BuzzerPin, HIGH);     // buzzer on, sends an continuous sound
     delay(20000);
     digitalWrite(BuzzerPin, LOW);      // buzzer off
   }  
   digitalWrite(DonePin, HIGH);        // TPL5110 "DONE" to high  
   delay(100);                 
   digitalWrite(DonePin, LOW);         // TPL5110 "DONE" to low for power off
   } 
void display() {                       // Function for testing purpose
   Serial.print("sensor : ");
   Serial.print(SoilMoistureValue);
   Serial.print("  min  : ");
   Serial.print(SoilMoistureMin);
   Serial.print(" batt : ");
   Serial.println(BattValue);   delay(1000);
}
